@@ -10,7 +10,7 @@ import re
 import sys
 import tempfile
 import time
-from inspect import signature
+from funcsigs import signature
 
 import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -239,8 +239,97 @@ class GracieBaseAPI(GracieAPIResponseError, GracieError, GracieAuthError, Gracie
         if hasattr(response, 'json'):
             return response.json()['response']
 
+    @property
+    def wait_for_task_complete(self):
+        return self.wait_for_task_complete
 
-class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
+    @wait_for_task_complete.setter
+    def wait_for_task_complete(self, bool_val):
+        if not isinstance(bool_val, bool):
+            raise GracieError('Bad value - must be True or False')
+        self._wait_for_task_complete = bool_val
+
+    @property
+    def remove_task_data_on_complete(self):
+        return self._remove_task_data_on_complete
+
+    @remove_task_data_on_complete.setter
+    def remove_task_data_on_complete(self, bool_val):
+        if not isinstance(bool_val, bool):
+            raise GracieError('Bad value - must be True or False')
+        self._remove_task_data_on_complete = bool_val
+
+    @property
+    def download_file_location(self):
+        return self.download_file_location
+
+    @download_file_location.setter
+    def download_file_location(self, bool_val):
+        if not isinstance(bool_val, bool):
+            raise GracieError('Bad value - must be True or False')
+        self.download_file_location = bool_val
+
+    @property
+    def full_results(self):
+        return self._full_results
+
+    @full_results.setter
+    def full_results(self, bool_val):
+        if not isinstance(bool_val, bool):
+            raise GracieError('Bad value - must be True or False')
+        self._full_results = bool_val
+
+    def _get_api_from_controller(self, controller_name, api):
+        gac = GracieApiClassLoader(CONTROLLERS_CLASSES_PATH, self)
+        controller_class = gac.load_class(controller_name)
+
+        api_class_method = getattr(controller_class, api)
+        sig = signature(api_class_method)
+
+        function_params = []
+        has_kawargs = False
+        for k, v in sig.parameters.items():
+            if k == 'kwargs':
+                has_kawargs = True
+            elif k != 'self':
+                function_params.append(str(v))
+        if has_kawargs:
+            function_params.append('**kwargs')
+
+        return len(sig.parameters), api_class_method, function_params
+
+    def _wait_for_task_results(self, task_data, remove_results=True, sleep_time=1):
+        while True:
+            if task_data and 'status' in task_data:
+
+                if server_type == 'feeds' and 'taskId' in task_data:
+                    task_id = task_data['taskId']
+                elif 'id' in task_data:
+                    task_id = task_data['id']
+                else:
+                    raise GracieAPIResponseError('Task id not found in results')
+
+                task_data = self.call_api('tasksController', 'retrieve', id=task_id)
+                if (task_data and 'status' in task_data) and (
+                        type(task_data['status']) is str or type(task_data['status']) is unicode
+                ) and (
+                        task_data['status'].lower() == 'completed' or task_data['status'].lower() == 'failed'
+                ):
+                    break
+            time.sleep(sleep_time)
+
+        if remove_results:
+            self.call_api('tasksController', 'delete', id=task_id)
+            if task_data['error']:
+                raise GracieError(task_data['error'])
+
+        if self._full_results:
+            return task_data
+        else:
+            return task_data['result']
+
+
+class GracieAPI(GracieBaseAPI, GracieApiClassLoader):
     """GracieAPI - Gracie AI platform API wrapper.
 
     Attributes:
@@ -249,6 +338,7 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
         full_results: Return full results from API calls, not just results from search
     """
 
+    _gracie = None
     _gracie_host = None
     _port = 443
     _verify_ssl = False
@@ -298,99 +388,8 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
             self._api_prefix = api_prefix
 
         GracieBaseAPI.__init__(self)
-        GracieApiClassLoader.__init__(self, CONTROLLERS_CLASSES_PATH)
         GracieSSOAuth.__init__(self, sso_host, login_name, login_password, verify_ssl)
 
-    @property
-    def wait_for_task_complete(self):
-        return self.wait_for_task_complete
-
-    @wait_for_task_complete.setter
-    def wait_for_task_complete(self, bool_val):
-        if not isinstance(bool_val, bool):
-            raise GracieError('Bad value - must be True or False')
-        self._wait_for_task_complete = bool_val
-
-    @property
-    def remove_task_data_on_complete(self):
-        return self._remove_task_data_on_complete
-
-    @remove_task_data_on_complete.setter
-    def remove_task_data_on_complete(self, bool_val):
-        if not isinstance(bool_val, bool):
-            raise GracieError('Bad value - must be True or False')
-        self._remove_task_data_on_complete = bool_val
-
-    @property
-    def download_file_location(self):
-        return self.download_file_location
-
-    @download_file_location.setter
-    def download_file_location(self, bool_val):
-        if not isinstance(bool_val, bool):
-            raise GracieError('Bad value - must be True or False')
-        self.download_file_location = bool_val
-
-    @property
-    def full_results(self):
-        return self._full_results
-
-    @full_results.setter
-    def full_results(self, bool_val):
-        if not isinstance(bool_val, bool):
-            raise GracieError('Bad value - must be True or False')
-        self._full_results = bool_val
-
-    def _get_api_from_controller(self, controller_name, api):
-        if controller_name not in self._controller_classes:
-            raise GracieError('Invalid controller')
-
-        if api not in self._controller_classes[controller_name].__dict__.keys():
-            raise GracieError('%s API does not exist in controller' % api)
-
-        api_class_method = getattr(self._controller_classes[controller_name], api)
-        sig = signature(api_class_method)
-
-        function_params = ['self']
-        has_kawargs = False
-        for k, v in sig.parameters.items():
-            if k == 'kwargs':
-                has_kawargs = True
-            elif k != 'self':
-                function_params.append(str(v))
-        if has_kawargs:
-            function_params.append('**kwargs')
-
-        return len(sig.parameters), api_class_method, function_params
-
-    def _wait_for_task_results(self, task_data, remove_results=True, sleep_time=1):
-        while True:
-            if task_data and 'status' in task_data:
-
-                if server_type == 'feeds' and 'taskId' in task_data:
-                    task_id = task_data['taskId']
-                elif 'id' in task_data:
-                    task_id = task_data['id']
-                else:
-                    raise GracieAPIResponseError('Task id not found in results')
-
-                task_data = self.call_api('tasksController', 'retrieve', id=task_id)
-                if task_data and 'status' in task_data and \
-                        type(task_data['status']) is str and \
-                        (task_data['status'].lower() == 'completed' or task_data['status'].lower() == 'failed'):
-                    break
-            time.sleep(sleep_time)
-
-        if remove_results:
-            self.call_api('tasksController', 'delete', id=task_id)
-            if task_data['error']:
-                raise GracieError(task_data['error'])
-
-        if self._full_results:
-            return task_data
-        else:
-            return task_data['result']
-
     def call_api(self, controller_name, api, **kwargs):
         """Gracie API request
 
@@ -417,7 +416,8 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
                     del _kwargs[p]
                     found = True
                 if not found and p != 'self' and p != '**kwargs':
-                    function_params.remove('self')
+                    if 'self' in function_params:
+                        function_params.remove('self')
                     raise GracieError('Missing API parameter(s) "%s" for %s' % (', '.join(function_params),
                                                                                 self._controller_name),
                                       'Required parameter: %s' % ', '.join(function_params))
@@ -425,10 +425,7 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
         if _kwargs and len(_kwargs) > 0:
             kwargs = _kwargs
 
-        # counter = 0
         while True:
-            # counter += 1
-            # try:
             api_ret_data = eval(function_sig)
             if controller_name != 'tasksController' and \
                     'status' in api_ret_data and \
@@ -436,9 +433,3 @@ class GracieAPI(GracieApiClassLoader, GracieBaseAPI):
                     self._wait_for_task_complete:
                 return self._wait_for_task_results(api_ret_data, self._remove_task_data_on_complete)
             return api_ret_data
-
-            # except GracieAPIResponseError as e:
-            #     if counter > 2 or e.message == 401:
-            #         raise GracieError('API error: (%s) %s' % (e.parameter, ' - '.join(e.args)))
-            #     else:
-            #         break
