@@ -1,18 +1,19 @@
-from gracie_dictionary_api import GracieBaseAPI
-
-
-class abbreviationController(GracieBaseAPI):
+class abbreviationController:
     """Abbreviation Controller"""
 
     _controller_name = "abbreviationController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def addAbbreviation(self, abbreviationText, categoryName, **kwargs):
         """
 
         Args:
-            abbreviationText: (string): abbreviationText
-            categoryName: (string): categoryName
-            languageId: (string): languageId
+            abbreviationText: (string): Text of abbreviation to be added, should end in "."
+            categoryName: (string): Name of category
+            languageId: (string): Language id for new abbreviation in a category, default to user language
 
         Consumes:
             application/json
@@ -26,15 +27,15 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/addAbbreviation'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def addCategory(self, name, **kwargs):
         """
 
         Args:
-            languageId: (string): languageId
-            name: (string): name
+            languageId: (string): Language id for new abbreviation category, default to user language
+            name: (string): Name of new category
 
         Consumes:
             application/json
@@ -48,16 +49,16 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/addCategory'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def deleteAbbreviation(self, abbreviationText, categoryName, **kwargs):
         """
 
         Args:
-            abbreviationText: (string): abbreviationText
-            categoryName: (string): categoryName
-            languageId: (string): languageId
+            abbreviationText: (string): Text of abbreviation to delete
+            categoryName: (string): Name of category
+            languageId: (string): Language id of abbreviation from a category to delete, default to user language
 
         Consumes:
             application/json
@@ -71,15 +72,15 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/deleteAbbreviation'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def deleteCategory(self, name, **kwargs):
         """
 
         Args:
-            languageId: (string): languageId
-            name: (string): name
+            languageId: (string): Language id of abbreviation category to delete, default to user language
+            name: (string): Name of category to delete
 
         Consumes:
             application/json
@@ -93,15 +94,15 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/deleteCategory'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def listAbbreviations(self, categoryName, **kwargs):
         """
 
         Args:
-            categoryName: (string): categoryName
-            languageId: (string): languageId
+            categoryName: (string): Name of category to list
+            languageId: (string): Language id for results, default to user language
 
         Consumes:
             application/json
@@ -115,14 +116,14 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/listAbbreviations'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def listCategories(self, **kwargs):
         """
 
         Args:
-            languageId: (string): languageId
+            languageId: (string): Language id of results, default to user language
 
         Consumes:
             application/json
@@ -136,5 +137,5 @@ class abbreviationController(GracieBaseAPI):
         api = '/abbreviation/listCategories'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
