@@ -1,17 +1,18 @@
-from gracie_dictionary_api import GracieBaseAPI
-
-
-class classStatusController(GracieBaseAPI):
+class classStatusController:
     """Class Status Controller"""
 
     _controller_name = "classStatusController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def list(self, **kwargs):
         """
 
         Args:
-            languageId: (string): languageId
-            scope: (string): scope
+            languageId: (string): Language id for results, default to user language
+            scope: (string): Class scope to retrieve:  All, Skills, TopicDictionaries, GeoDictionaries, Profiles, ClusterSets, Pipelines
 
         Consumes:
             application/json
@@ -25,15 +26,15 @@ class classStatusController(GracieBaseAPI):
         api = '/classStatus/list'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, classId, **kwargs):
         """
 
         Args:
-            classId: (string): classId
-            languageId: (string): languageId
+            classId: (string): Id of class { dictionaryId, topicTypeId, skillId, profileId } to retrieve
+            languageId: (string): Language id for results, default to user language
 
         Consumes:
             application/json
@@ -47,5 +48,5 @@ class classStatusController(GracieBaseAPI):
         api = '/classStatus/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
