@@ -1,16 +1,17 @@
-from gracie_dictionary_api import GracieBaseAPI
-
-
-class performanceController(GracieBaseAPI):
+class performanceController:
     """Performance Controller"""
 
     _controller_name = "performanceController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def enable(self, enabled):
         """
 
         Args:
-            enabled: (boolean): enabled
+            enabled: (boolean): Enable/disable runtime server engine performance logging
 
         Consumes:
             application/json
@@ -24,8 +25,8 @@ class performanceController(GracieBaseAPI):
         api = '/performance/enable'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self):
         """"""
@@ -35,5 +36,5 @@ class performanceController(GracieBaseAPI):
         api = '/performance/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
