@@ -1,18 +1,19 @@
-from gracie_dictionary_api import GracieBaseAPI
-
-
-class summarizerController(GracieBaseAPI):
+class summarizerController:
     """Summarizer Controller"""
 
     _controller_name = "summarizerController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def summarize(self, maxSentences, text, **kwargs):
         """
 
         Args:
-            languageId: (string): languageId
-            maxSentences: (integer): maxSentences
-            text: (type): text
+            languageId: (string): Id of language to use for processing, default is to auto-detect language
+            maxSentences: (integer): Maximum number of sentences to return in summary
+            text: (type): Text to summarize
 
         Consumes:
             application/json
@@ -26,5 +27,5 @@ class summarizerController(GracieBaseAPI):
         api = '/summarize'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
