@@ -1,10 +1,11 @@
-from gracie_dictionary_api import GracieBaseAPI
-
-
-class userTypesController(GracieBaseAPI):
+class userTypesController:
     """User Types Controller"""
 
     _controller_name = "userTypesController"
+    _gracie = None
+
+    def __init__(self, gracie):
+        self._gracie = gracie
 
     def list(self):
         """"""
@@ -14,14 +15,14 @@ class userTypesController(GracieBaseAPI):
         api = '/user-types/list'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
         """
 
         Args:
-            id: (string): id
+            id: (string): Id of user type to retrieve
 
         Consumes:
             application/json
@@ -35,5 +36,5 @@ class userTypesController(GracieBaseAPI):
         api = '/user-types/retrieve'
         actions = ['post']
         consumes = ['application/json']
-        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
-        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+        params, data = self._gracie._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._gracie._process_api(self._controller_name, api, actions, params, data, consumes)
